ReST provides classes and functions augmenting docutil's reStructuredText
handling:

* Directives `vimeo` and `youtube` for video elements

* Roles `email` and `tel` for `mailto` and `tel` links

* Callable `to_html` that converts ReST to HTML with a configurable
  list of `replacers` that run over the generated HTML

ReST is distributed under the conditions of the `BSD 3-Clause
License <http://www.c-tanzer.at/license/bsd_3c.html>`_.

ReST is available as a `git repository`_.
You can clone that repository with::

    git clone git@github.com:Tapyr/tapyr.git

Reports of bugs in ReST should be submitted to the `git repository`_.

.. _`git repository`: https://github.com/Tapyr/tapyr
